+++++++++
Polar Sky
+++++++++

The PolarSky plugin draws a polar plot on the Targets channel and 
shows a small window with astronomical almanac info (sun set/rise, 
moon set/rise, twilights, etc).

Since the polar plot guides are useful in interpreting the plots of
targets, etc. you will usually want to start this plugin if you are
planning to also use the :doc:`targetlist` or :doc:`visplot` plugins.
If you are not interested in the almanac info you can minimize the
plugin UI after starting it.

.. image:: figures/PolarSky.*

===============
PolarSky Window
===============

The PolarSky channel contains time information for the site, the sun, and 
the moon. Under "Site Date/Time", it has the date in yyyy-mm-dd, local time 
and time zone, UTC time and date in mm/dd, and LST. 

